<!-- sxlink2html.xsl: a collection of named templates to call 
     for converting XLink simple links to HTML.
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                version="1.0">

  <xsl:output method="html"/>

  <!-- Named templates to call from any        -->
  <!-- template that finds xlink:type="simple" -->        

  <xsl:template name="SimpleLinkOnLoad">

    <xsl:choose>

    <xsl:when test="@xlink:show='embed'">
      <!-- Read the external document in immediately. -->
      <xsl:apply-templates select="document(@xlink:href)"/>
    </xsl:when>

    <xsl:when test="@xlink:show='new'">
      <!-- Display href document in separate -->
      <!-- window right away ("onLoad").     -->
      <script language="JavaScript">
        <xsl:comment>
        open("<xsl:value-of select='@xlink:href'/>",
             "_blank","toolbar=no,scrollbars=no,resizable=1");
        </xsl:comment>
      </script>
    </xsl:when>

    <xsl:when test="@xlink:show='replace'">
      <!-- These are supposed to go inside the HTML HEAD element,  -->
      <!-- but in the BODY, it still works for IE5 and Netscape 6. -->
      <META HTTP-EQUIV="Refresh" 
        CONTENT="0; URL={@xlink:href}"/>
    </xsl:when>

    </xsl:choose>

    <xsl:apply-templates/>

  </xsl:template>


  <xsl:template name="SimpleLinkOnRequest">

    <xsl:element name="a">

      <!-- An onRequest simple link is all about which        -->
      <!-- attributes to add to a traditional HTML a element. -->

      <xsl:attribute name="href">
        <xsl:value-of select="@xlink:href"/>
      </xsl:attribute>

      <xsl:choose>

        <xsl:when test="@xlink:show='embed'">
          <!-- Can't implement on client side -->
          <!-- using HTML+JavaScript.         -->
          <!-- 5 out of 6 ain't bad!          -->
        </xsl:when>

        <xsl:when test="@xlink:show='new'">
          <!-- Display target document in a new widow. -->
          <xsl:attribute name="target">_blank</xsl:attribute>
        </xsl:when>

        <!-- Following not necessary, because replacing 
             document with target document on clicking 
             of link is default behavior of HTML A element.
        <xsl:when test="@xlink:show='replace'">
        </xsl:when>
        -->
      </xsl:choose>

      <xsl:if test="@xlink:title">
        <!-- In current IE and Navigator, a element's  -->
        <!-- title value pops up for onMouseOver.      -->
        <xsl:attribute name="title">
          <xsl:value-of select="@xlink:title"/>
        </xsl:attribute>
      </xsl:if>

      <!-- 5.5 of XLink spec: The value of the role or     -->
      <!-- arcrole attribute must be a URI reference...the -->
      <!-- URI reference identifies some resource that     -->
      <!-- describes the intended property.                -->

      <xsl:if test="@xlink:role='http://www.snee.com/roles/pay'">
        <!-- To show that this link costs, turn text to -->
        <!-- green for onMouseOver then back to blue.   -->
        <xsl:attribute name="onMouseOver">
         <xsl:text>style.color="green"</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="onMouseOut">
         <xsl:text>style.color="blue"</xsl:text>
        </xsl:attribute>
      </xsl:if>

    <xsl:apply-templates/>

    </xsl:element>

  </xsl:template>

</xsl:stylesheet>
